

set -ex



test -f $PREFIX/lib/libabsl_scoped_mock_log${SHLIB_EXT}
test ! -f $PREFIX/lib/libabsl_scoped_mock_log.a
pkg-config --print-errors --exact-version "20240116" absl_scoped_mock_log
cd cmake_test
export CMAKE_ARGS="$CMAKE_ARGS -GNinja -DCMAKE_BUILD_TYPE=Release"
cmake $CMAKE_ARGS  -DCMAKE_CXX_STANDARD=17 .
export TRY_TEST_TARGET=1
cmake --build .
./flags_example
exit 0
